"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _textlintUtilToString = require("textlint-util-to-string");

var _kuromojin = require("kuromojin");

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * アルゴリズム
 *
 * - Paragraphから文を抽出する
 * - Str nodeだけを見ると`A`と`B` のようなCodeに囲まれたものが、「と」となりフィラーと誤検知される
 * - そのため、Paragraphから装飾を取り除き、Codeはマスクした文章を作成する
 */
var maskCodeNode = codeNode => {
  return _objectSpread(_objectSpread({}, codeNode), {}, {
    value: codeNode.value.replace(/./g, "X")
  });
};

var sourceWithoutStyle = node => {
  var nodeMaskedCode = _objectSpread(_objectSpread({}, node), {}, {
    children: node.children.map(childNode => {
      if (childNode.type === "Code") {
        return maskCodeNode(childNode);
      }

      return childNode;
    })
  });

  return new _textlintUtilToString.StringSource(nodeMaskedCode);
};

var report = context => {
  var {
    Syntax,
    RuleError,
    report
  } = context;
  return {
    [Syntax.Paragraph](node) {
      return _asyncToGenerator(function* () {
        var source = sourceWithoutStyle(node);
        var tokens = yield (0, _kuromojin.tokenize)(source.toString());
        tokens.forEach(token => {
          if (token.pos === "フィラー") {
            var index = token.word_position - 1;
            var originalIndex = source.originalIndexFromIndex(index);
            report(node, new RuleError("\u30D5\u30A3\u30E9\u30FC\uFF08\u7E4B\u304E\u8868\u73FE\uFF09\u3067\u3042\u308B\u300C".concat(token.surface_form, "\u300D\u3092\u691C\u77E5\u3057\u307E\u3057\u305F\u3002\n                        \n\u300C\u3048\u30FC\u3068\u300D\u300C\u3042\u306E\u300D\u300C\u307E\u3042\u300D\u306A\u3069\u306E\u7E4B\u304E\u8868\u73FE\u306F\u8A71\u3057\u8A00\u8449\uFF08\u53E3\u8A9E\uFF09\u3067\u3042\u308B\u305F\u3081\u3001\u6587\u7AE0\u3092\u8AAD\u307F\u306B\u304F\u304F\u3057\u307E\u3059\u3002"), {
              index: originalIndex
            }));
          }
        });
      })();
    }

  };
};

var _default = report;
exports.default = _default;
//# sourceMappingURL=textlint-rule-no-filler.js.map